@@ -109,6 +109,46 @@ def set_part_number(part_id: int, ipn: str) -> bool:
         return False
 
 
+def get_part_from_ipn(part_ipn='') -> int:
+    ''' Get Part ID from Part IPN '''
+    global inventree_api
+
+    parts = Part.list(inventree_api)
+
+    for part in parts:
+        if part.IPN == part_ipn:
+            return part
+    
+    # No part found
+    return None
+
+
+def fetch_part(part_id='', part_ipn='') -> int:
+    ''' Fetch part from database using either ID or IPN '''
+    from requests.exceptions import HTTPError
+    global inventree_api
+
+    part = None
+    if part_id:
+        try:
+            part = Part(inventree_api, part_id)
+        except TypeError:
+            # Part ID is invalid (eg. decimal value)
+            cprint('[TREE] Error: Part ID type is invalid')
+        except ValueError:
+            # Part ID is not a positive integer
+            cprint('[TREE] Error: Part ID must be positive')
+        except HTTPError:
+            # Part ID does not exist
+            cprint('[TREE] Error: Part ID does not exist in database')
+    elif part_ipn:
+        part = get_part_from_ipn(part_ipn)
+    else:
+        pass
+
+    return part
+
+
 def is_new_part(category_id: int, part_info: dict) -> int:
     ''' Check if part exists based on parameters (or description) '''
     global inventree_api
@@ -309,16 +349,23 @@ def create_company(company_name: str, manufacturer=False, supplier=False) -> boo
     return company
 
 
-def get_company_id(company_name: str) -> int:
-    ''' Get company (supplier/manufacturer) primary key (ID) '''
+def get_all_companies() -> dict:
+    ''' Get all existing companies (supplier/manufacturer) from database '''
     global inventree_api
 
     company_list = Company.list(inventree_api)
     companies = {}
     for company in company_list:
         companies[company.name] = company.pk
+
+    return companies
+
+
+def get_company_id(company_name: str) -> int:
+    ''' Get company (supplier/manufacturer) primary key (ID) '''
+
     try:
-        return companies[company_name]
+        return get_all_companies()[company_name]
     except:
         return 0
 
